import"./VRow-Dwx696kb.js";import{u as t,a as r,m as l,b as i,c as m}from"./index-w-dkzpPh.js";import{g as c,p as u,E as p,c as C,n as d,a as f}from"./index-DPl16C00.js";const y=u({fluid:{type:Boolean,default:!1},...m(),...i(),...l()},"VContainer"),v=c()({name:"VContainer",props:y(),setup(e,a){let{slots:s}=a;const{rtlClasses:n}=p(),{dimensionStyles:o}=t(e);return r(()=>C(e.tag,{class:f(["v-container",{"v-container--fluid":e.fluid},n.value,e.class]),style:d([o.value,e.style])},s)),{}}});export{v as V};
