import{f as v,a as b,m as h,k as f,c as u,p as c}from"./index-w-dkzpPh.js";import{g,p as y,D as x,c as s,n as V,a as T,m as k,b as d,j as p}from"./index-DPl16C00.js";const C=y({fixedHeader:Boolean,fixedFooter:Boolean,height:[Number,String],hover:Boolean,striped:{type:String,default:null,validator:e=>["even","odd"].includes(e)},...u(),...f(),...h(),...k()},"VTable"),F=g()({name:"VTable",props:C(),setup(e,n){let{slots:a,emit:P}=n;const{themeClasses:r}=x(e),{densityClasses:i}=v(e);return b(()=>{const m={VCheckboxBtn:{density:e.density}};return s(e.tag,{class:T(["v-table",{"v-table--fixed-height":!!e.height,"v-table--fixed-header":e.fixedHeader,"v-table--fixed-footer":e.fixedFooter,"v-table--has-top":!!a.top,"v-table--has-bottom":!!a.bottom,"v-table--hover":e.hover,"v-table--striped-even":e.striped==="even","v-table--striped-odd":e.striped==="odd"},r.value,i.value,e.class]),style:V(e.style)},{default:()=>{var t,l;return[(t=a.top)==null?void 0:t.call(a),s(c,{defaults:m},{default:()=>{var o;return[a.default?d("div",{class:"v-table__wrapper",style:{height:p(e.height)}},[d("table",null,[a.default()])]):(o=a.wrapper)==null?void 0:o.call(a)]}}),(l=a.bottom)==null?void 0:l.call(a)]}})}),{}}});export{F as V};
