import{m as g,V as r}from"./VCheckboxBtn-BS0WhS02.js";import{a as A,m as B,V as l}from"./VInput-qFshDEqa.js";import{f as F}from"./forwardRefs-BQ8_JL2J.js";import{g as R,p as U,h as w,B as D,G,ad as M,aS as N,c as u,X as d}from"./index-DPl16C00.js";import{a as S}from"./index-w-dkzpPh.js";const X=U({...B(),...G(g(),["inline"])},"VCheckbox"),H=R()({name:"VCheckbox",inheritAttrs:!1,props:X(),emits:{"update:modelValue":e=>!0,"update:focused":e=>!0},setup(e,c){let{attrs:n,slots:a}=c;const s=w(e,"modelValue"),{isFocused:i,focus:m,blur:f}=A(e),t=D(),V=M();return S(()=>{const[p,b]=N(n),k=l.filterProps(e),v=r.filterProps(e);return u(l,d({ref:t,class:["v-checkbox",e.class]},p,k,{modelValue:s.value,"onUpdate:modelValue":o=>s.value=o,id:e.id||`checkbox-${V}`,focused:i.value,style:e.style}),{...a,default:o=>{let{id:h,messagesId:x,isDisabled:P,isReadonly:C,isValid:y}=o;return u(r,d(v,{id:h.value,"aria-describedby":x.value,disabled:P.value,readonly:C.value},b,{error:y.value===!1,modelValue:s.value,"onUpdate:modelValue":I=>s.value=I,onFocus:m,onBlur:f}),a)}})}),F({},t)}});export{H as V};
