if(!self.define){let s,e={};const l=(l,i)=>(l=new URL(l+".js",i).href,e[l]||new Promise(e=>{if("document"in self){const s=document.createElement("script");s.src=l,s.onload=e,document.head.appendChild(s)}else s=l,importScripts(l),e()}).then(()=>{let s=e[l];if(!s)throw new Error(`Module ${l} didn’t register its module`);return s}));self.define=(i,n)=>{const r=s||("document"in self?document.currentScript.src:"")||location.href;if(e[r])return;let u={};const o=s=>l(s,r),t={module:{uri:r},exports:u,require:o};e[r]=Promise.all(i.map(s=>t[s]||o(s))).then(s=>(n(...s),u))}}define(["./workbox-e3490c72"],function(s){"use strict";self.addEventListener("message",s=>{s.data&&"SKIP_WAITING"===s.data.type&&self.skipWaiting()}),s.precacheAndRoute([{url:"assets/_plugin-vue_export-helper-DlAUqK2U.js",revision:null},{url:"assets/CoreConfigs-D_BQ-vpt.css",revision:null},{url:"assets/CoreConfigs-DEfFljc_.js",revision:null},{url:"assets/Default-BDThR6s7.css",revision:null},{url:"assets/Default-WJ7l1Cti.js",revision:null},{url:"assets/Devices-CnIfayh_.js",revision:null},{url:"assets/Devices-D-aLGUNa.css",revision:null},{url:"assets/EditDeviceConfig-DknyoRg2.js",revision:null},{url:"assets/EditDeviceConfig-DYx9Yjpx.css",revision:null},{url:"assets/Forecast-BDI45g3v.js",revision:null},{url:"assets/Forecast-BRJNisiW.js",revision:null},{url:"assets/forwardRefs-BQ8_JL2J.js",revision:null},{url:"assets/forwardRefs-CUbsK2SS.css",revision:null},{url:"assets/group-bVGzOFiw.js",revision:null},{url:"assets/Home-BScxIPOf.js",revision:null},{url:"assets/index-Cb3masFi.css",revision:null},{url:"assets/index-CJMosIp2.js",revision:null},{url:"assets/index-D-QfZ6QT.css",revision:null},{url:"assets/index-DPl16C00.js",revision:null},{url:"assets/index-w-dkzpPh.js",revision:null},{url:"assets/layout-DPDN2kkE.js",revision:null},{url:"assets/PowerFlowCard-B6RsybhN.css",revision:null},{url:"assets/PowerFlowCard-D8HZJYDX.js",revision:null},{url:"assets/RawData-BWipxmn5.css",revision:null},{url:"assets/RawData-CU3fIF7D.js",revision:null},{url:"assets/scopeId-C7DHxJXu.js",revision:null},{url:"assets/scopeId-DhM-bArL.css",revision:null},{url:"assets/SessionLog-50KpewNY.js",revision:null},{url:"assets/SessionLog-C_Pjwgt2.css",revision:null},{url:"assets/Settings-8seYfuyp.js",revision:null},{url:"assets/Statistics-BKY9g5mJ.js",revision:null},{url:"assets/utils-D98hIld_.js",revision:null},{url:"assets/VBtn-ClDdYB5F.js",revision:null},{url:"assets/VBtn-D9x-UhCY.css",revision:null},{url:"assets/VCard-CJTiHjO-.js",revision:null},{url:"assets/VCard-XVfcVNgo.css",revision:null},{url:"assets/VCheckbox-B8xY4Saw.css",revision:null},{url:"assets/VCheckbox-CYlyT7u6.js",revision:null},{url:"assets/VCheckboxBtn-BS0WhS02.js",revision:null},{url:"assets/VContainer-DfBRv9y0.js",revision:null},{url:"assets/VDivider-C9pogIUa.css",revision:null},{url:"assets/VDivider-Dr0TEagO.js",revision:null},{url:"assets/VForm-v9rzANiR.js",revision:null},{url:"assets/VImg-B-97Yzkt.js",revision:null},{url:"assets/VImg-BjaFO4OY.css",revision:null},{url:"assets/VInput-BVDHa5Qw.css",revision:null},{url:"assets/VInput-qFshDEqa.js",revision:null},{url:"assets/VRow-DCJ49FnP.css",revision:null},{url:"assets/VRow-Dwx696kb.js",revision:null},{url:"assets/VSelect-Dtf2lpH6.js",revision:null},{url:"assets/VSelect-DwiHcnbS.css",revision:null},{url:"assets/VSelectionControl-Bk1rsVbC.css",revision:null},{url:"assets/VSelectionControl-MTkDIXZh.js",revision:null},{url:"assets/VTable-6liiu1di.css",revision:null},{url:"assets/VTable-Cuh47MPV.js",revision:null},{url:"assets/VTabs-D03hRKPL.js",revision:null},{url:"assets/VTabs-DNgDg5lj.css",revision:null},{url:"assets/VTextField-B2kQUS-C.css",revision:null},{url:"assets/VTextField-BpJ2unt4.js",revision:null},{url:"assets/VToolbar-B8r0q3D8.css",revision:null},{url:"assets/VToolbar-CbiRZXlD.js",revision:null},{url:"assets/workbox-window.prod.es5-CwtvwXb3.js",revision:null},{url:"index.html",revision:"6608711ba4c310cb1e869a32bfdf4ef9"},{url:"apple-touch-icon.png",revision:"ec84610d7d85b67822bcb8a7f5114354"},{url:"pwa-192x192.png",revision:"568e4ca3a35484f7b1cd02882e9e8ac0"},{url:"pwa-512x512.png",revision:"1e5320b35c3f539c43a9132b901bb0e9"},{url:"robots.txt",revision:"f77c87f977e0fcce05a6df46c885a129"},{url:"manifest.webmanifest",revision:"911eb90ebc08b99acb4dad0970acf877"}],{}),s.cleanupOutdatedCaches(),s.registerRoute(new s.NavigationRoute(s.createHandlerBoundToURL("index.html")))});
