import{o as m,a as u,c as h}from"./index-w-dkzpPh.js";import{g,p as y,D as f,f as C,j as s,m as _,b as r,n as b,a as l}from"./index-DPl16C00.js";const S=y({color:String,inset:Boolean,length:[Number,String],opacity:[Number,String],thickness:[Number,String],vertical:Boolean,...h(),..._()},"VDivider"),D=g()({name:"VDivider",props:S(),setup(e,n){let{attrs:i,slots:a}=n;const{themeClasses:o}=f(e),{textColorClasses:d,textColorStyles:v}=m(()=>e.color),c=C(()=>{const t={};return e.length&&(t[e.vertical?"height":"width"]=s(e.length)),e.thickness&&(t[e.vertical?"borderRightWidth":"borderTopWidth"]=s(e.thickness)),t});return u(()=>{const t=r("hr",{class:l([{"v-divider":!0,"v-divider--inset":e.inset,"v-divider--vertical":e.vertical},o.value,d.value,e.class]),style:b([c.value,v.value,{"--v-border-opacity":e.opacity},e.style]),"aria-orientation":!i.role||i.role==="separator"?e.vertical?"vertical":"horizontal":void 0,role:`${i.role||"separator"}`},null);return a.default?r("div",{class:l(["v-divider__wrapper",{"v-divider__wrapper--vertical":e.vertical,"v-divider__wrapper--inset":e.inset}])},[t,r("div",{class:"v-divider__content"},[a.default()]),t]):t}),{}}});export{D as V};
