import{k as f,f as v,W as g,s as _,c as e,b as V,w as t,z as o,M as b,$ as r,r as x,o as c,x as n,y as i,d as k,e as B}from"./index-DPl16C00.js";import{V as T}from"./VToolbar-CbiRZXlD.js";import{V as h}from"./VDivider-Dr0TEagO.js";import{V as w,a as l}from"./VTabs-D03hRKPL.js";import"./index-w-dkzpPh.js";import"./VImg-B-97Yzkt.js";import"./VBtn-ClDdYB5F.js";import"./group-bVGzOFiw.js";import"./forwardRefs-BQ8_JL2J.js";import"./scopeId-C7DHxJXu.js";const j=f({__name:"Settings",setup(y){const u=g(),m=v(()=>{var s,a;return(s=u.currentRoute.value.name)!=null&&s.toString().includes("forecast")?"forecast":(a=u.currentRoute.value.name)!=null&&a.toString().includes("core")?"core":"devices"});return(s,a)=>{const p=x("router-view");return c(),_("div",null,[e(T,{color:"transparent",title:o(b)("bp4")?o(r)("app.settings"):""},{append:t(()=>[e(w,{"model-value":m.value,"align-tabs":"end",height:"100%"},{default:t(()=>[e(l,{value:"devices",to:{name:"devicessettings"}},{default:t(()=>[n(i(o(r)("settings.devices")),1)]),_:1}),e(l,{value:"forecast",to:{name:"forecastsettings"}},{default:t(()=>[n(i(o(r)("settings.forecast")),1)]),_:1}),e(l,{value:"core",to:{name:"coresettings"}},{default:t(()=>[n(i(o(r)("settings.core")),1)]),_:1})]),_:1},8,["model-value"])]),_:1},8,["title"]),e(h),a[0]||(a[0]=V("div",{style:{height:"15px"}},null,-1)),e(p,null,{default:t(({Component:d})=>[(c(),k(B(d)))]),_:1})])}}});export{j as default};
